pub struct Sidebar {Show 16 fields
pub(super) header_bar: TemplateChild<HeaderBar>,
account_switcher_button: TemplateChild<AccountSwitcherButton>,
security_banner: TemplateChild<Banner>,
scrolled_window: TemplateChild<ScrolledWindow>,
listview: TemplateChild<ListView>,
room_search_entry: TemplateChild<SearchEntry>,
pub(super) room_search: TemplateChild<SearchBar>,
room_row_menu: TemplateChild<MenuModel>,
room_row_popover: OnceCell<PopoverMenu>,
user: RefCell<Option<User>>,
pub(super) drop_source_category: Cell<Option<RoomCategory>>,
pub(super) drop_active_target_category: Cell<Option<TargetRoomCategory>>,
list_model: WeakRef<SidebarListModel>,
expr_watch: RefCell<Option<ExpressionWatch>>,
session_handler: RefCell<Option<SignalHandlerId>>,
security_handlers: RefCell<Vec<SignalHandlerId>>,
}Fields
header_bar: TemplateChild<HeaderBar>scrolled_window: TemplateChild<ScrolledWindow>listview: TemplateChild<ListView>room_search_entry: TemplateChild<SearchEntry>room_search: TemplateChild<SearchBar>room_row_popover: OnceCell<PopoverMenu>user: RefCell<Option<User>>The logged-in user.
drop_source_category: Cell<Option<RoomCategory>>The category of the source that activated drop mode.
drop_active_target_category: Cell<Option<TargetRoomCategory>>The category of the drop target that is currently hovered.
list_model: WeakRef<SidebarListModel>The list model of this sidebar.
expr_watch: RefCell<Option<ExpressionWatch>>session_handler: RefCell<Option<SignalHandlerId>>security_handlers: RefCell<Vec<SignalHandlerId>>Implementations
Sourceimpl Sidebar
impl Sidebar
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl Sidebar
impl Sidebar
Sourcefn set_list_model(&self, list_model: Option<&SidebarListModel>)
fn set_list_model(&self, list_model: Option<&SidebarListModel>)
Set the list model of the sidebar.
Update the security banner.
Sourcepub(super) fn set_drop_source_category(
&self,
source_category: Option<RoomCategory>,
)
pub(super) fn set_drop_source_category( &self, source_category: Option<RoomCategory>, )
Set the category of the source that activated drop mode.
Sourcepub(super) fn room_row_popover(&self) -> &PopoverMenu
pub(super) fn room_row_popover(&self) -> &PopoverMenu
The shared popover for a room row in the sidebar.
Sourcepub(super) fn scroll_to_selection(&self)
pub(super) fn scroll_to_selection(&self)
Scroll to the currently selected item of the sidebar.
Sourcefn fix_security_issue(&self)
fn fix_security_issue(&self)
Open the proper security flow to fix the current issue.